/* Copyright (c) 2013, The Linux Foundation. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 *       copyright notice, this list of conditions and the following
 *       disclaimer in the documentation and/or other materials provided
 *       with the distribution.
 *     * Neither the name of The Linux Foundation nor the names of its
 *       contributors may be used to endorse or promote products derived
 *       from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <stdint.h>
#include <msm_panel.h>
#include <mipi_dsi.h>
#include <sys/types.h>
#include <err.h>
#include <reg.h>
#include <mdp5.h>
#include <debug.h>
#include <platform/iomap.h>

static char disp_on0[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0xEE, 0xFF, 0xFF,
};
static char disp_on1[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x26, 0x08, 0xFF, 0xFF,
};
static char disp_on2[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x26, 0x00, 0xFF, 0xFF,
};
static char disp_on3[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x00, 0xFF, 0xFF,
};
static char lane[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBA, 0x03, 0xFF, 0xFF,
};
static char command_mode[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC2, 0x08, 0xFF, 0xFF,
};
static char video_mode[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC2, 0x03, 0xFF, 0xFF,
};
static char disp_on6[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x01, 0xFF, 0xFF,
};
static char disp_on7[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on8[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x00, 0x4A, 0xFF, 0xFF,
};
static char disp_on9[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x01, 0x33, 0xFF, 0xFF,
};
static char disp_on10[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x02, 0x53, 0xFF, 0xFF,
};
static char disp_on11[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x03, 0x55, 0xFF, 0xFF,
};
static char disp_on12[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x04, 0x55, 0xFF, 0xFF,
};
static char disp_on13[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x05, 0x33, 0xFF, 0xFF,
};
static char disp_on14[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x06, 0x22, 0xFF, 0xFF,
};
static char disp_on15[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x08, 0x56, 0xFF, 0xFF,
};
static char disp_on16[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x09, 0x8F, 0xFF, 0xFF,
};
static char disp_on17[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x36, 0x73, 0xFF, 0xFF,
};
static char disp_on18[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0B, 0x9F, 0xFF, 0xFF,
};
static char disp_on19[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0C, 0x9F, 0xFF, 0xFF,
};
static char disp_on20[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0D, 0x2F, 0xFF, 0xFF,
};
static char disp_on21[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0E, 0x24, 0xFF, 0xFF,
};
static char disp_on22[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x11, 0x83, 0xFF, 0xFF,
};
static char disp_on23[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x12, 0x03, 0xFF, 0xFF,
};
static char disp_on24[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x71, 0x2C, 0xFF, 0xFF,
};
static char disp_on25[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6F, 0x03, 0xFF, 0xFF,
};
static char disp_on26[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0F, 0x0A, 0xFF, 0xFF,
};
static char disp_on27[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x05, 0xFF, 0xFF,
};
static char disp_on28[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on29[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x01, 0x00, 0xFF, 0xFF,
};
static char disp_on30[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x02, 0x8B, 0xFF, 0xFF,
};
static char disp_on31[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x03, 0x82, 0xFF, 0xFF,
};
static char disp_on32[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x04, 0x82, 0xFF, 0xFF,
};
static char disp_on33[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x05, 0x30, 0xFF, 0xFF,
};
static char disp_on34[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x06, 0x33, 0xFF, 0xFF,
};
static char disp_on35[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x07, 0x01, 0xFF, 0xFF,
};
static char disp_on36[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x08, 0x00, 0xFF, 0xFF,
};
static char disp_on37[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x09, 0x46, 0xFF, 0xFF,
};
static char disp_on38[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0A, 0x46, 0xFF, 0xFF,
};
static char disp_on39[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0D, 0x0B, 0xFF, 0xFF,
};
static char disp_on40[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0E, 0x1D, 0xFF, 0xFF,
};
static char disp_on41[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0F, 0x08, 0xFF, 0xFF,
};
static char disp_on42[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x10, 0x53, 0xFF, 0xFF,
};
static char disp_on43[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x11, 0x00, 0xFF, 0xFF,
};
static char disp_on44[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x12, 0x00, 0xFF, 0xFF,
};
static char disp_on45[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x14, 0x01, 0xFF, 0xFF,
};
static char disp_on46[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x15, 0x00, 0xFF, 0xFF,
};
static char disp_on47[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x16, 0x05, 0xFF, 0xFF,
};
static char disp_on48[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x17, 0x00, 0xFF, 0xFF,
};
static char disp_on49[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x19, 0x7F, 0xFF, 0xFF,
};
static char disp_on50[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1A, 0xFF, 0xFF, 0xFF,
};
static char disp_on51[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1B, 0x0F, 0xFF, 0xFF,
};
static char disp_on52[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1C, 0x00, 0xFF, 0xFF,
};
static char disp_on53[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1D, 0x00, 0xFF, 0xFF,
};
static char disp_on54[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1E, 0x00, 0xFF, 0xFF,
};
static char disp_on55[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1F, 0x07, 0xFF, 0xFF,
};
static char disp_on56[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x20, 0x00, 0xFF, 0xFF,
};
static char disp_on57[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x21, 0x06, 0xFF, 0xFF,
};
static char disp_on58[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x22, 0x55, 0xFF, 0xFF,
};
static char disp_on59[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x23, 0x4D, 0xFF, 0xFF,
};
static char disp_on60[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x2D, 0x02, 0xFF, 0xFF,
};
static char disp_on61[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x28, 0x01, 0xFF, 0xFF,
};
static char disp_on62[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x2F, 0x02, 0xFF, 0xFF,
};
static char disp_on63[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x83, 0x01, 0xFF, 0xFF,
};
static char disp_on64[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9E, 0x58, 0xFF, 0xFF,
};
static char disp_on65[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9F, 0x6A, 0xFF, 0xFF,
};
static char disp_on66[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA0, 0x01, 0xFF, 0xFF,
};
static char disp_on67[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA2, 0x10, 0xFF, 0xFF,
};
static char disp_on68[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBB, 0x0A, 0xFF, 0xFF,
};
static char disp_on69[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBC, 0x0A, 0xFF, 0xFF,
};
static char disp_on70[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x32, 0x08, 0xFF, 0xFF,
};
static char disp_on71[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x33, 0xB8, 0xFF, 0xFF,
};
static char disp_on72[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x36, 0x01, 0xFF, 0xFF,
};
static char disp_on73[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x37, 0x00, 0xFF, 0xFF,
};
static char disp_on74[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x43, 0x00, 0xFF, 0xFF,
};
static char disp_on75[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4B, 0x21, 0xFF, 0xFF,
};
static char disp_on76[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4C, 0x03, 0xFF, 0xFF,
};
static char disp_on77[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x50, 0x21, 0xFF, 0xFF,
};
static char disp_on78[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x51, 0x03, 0xFF, 0xFF,
};
static char disp_on79[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x58, 0x21, 0xFF, 0xFF,
};
static char disp_on80[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x59, 0x03, 0xFF, 0xFF,
};
static char disp_on81[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5D, 0x21, 0xFF, 0xFF,
};
static char disp_on82[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5E, 0x03, 0xFF, 0xFF,
};
static char disp_on83[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6C, 0x00, 0xFF, 0xFF,
};
static char disp_on84[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6D, 0x00, 0xFF, 0xFF,
};
static char disp_on85[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on86[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x01, 0xFF, 0xFF,
};
static char disp_on87[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on88[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x75, 0x00, 0xFF, 0xFF,
};
static char disp_on89[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x76, 0x7D, 0xFF, 0xFF,
};
static char disp_on90[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x77, 0x00, 0xFF, 0xFF,
};
static char disp_on91[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x78, 0x8A, 0xFF, 0xFF,
};
static char disp_on92[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x79, 0x00, 0xFF, 0xFF,
};
static char disp_on93[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7A, 0x9C, 0xFF, 0xFF,
};
static char disp_on94[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7B, 0x00, 0xFF, 0xFF,
};
static char disp_on95[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7C, 0xB1, 0xFF, 0xFF,
};
static char disp_on96[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7D, 0x00, 0xFF, 0xFF,
};
static char disp_on97[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7E, 0xBF, 0xFF, 0xFF,
};
static char disp_on98[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7F, 0x00, 0xFF, 0xFF,
};
static char disp_on99[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x80, 0xCF, 0xFF, 0xFF,
};
static char disp_on100[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x81, 0x00, 0xFF, 0xFF,
};
static char disp_on101[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x82, 0xDD, 0xFF, 0xFF,
};
static char disp_on102[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x83, 0x00, 0xFF, 0xFF,
};
static char disp_on103[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x84, 0xE8, 0xFF, 0xFF,
};
static char disp_on104[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x85, 0x00, 0xFF, 0xFF,
};
static char disp_on105[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x86, 0xF2, 0xFF, 0xFF,
};
static char disp_on106[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x87, 0x01, 0xFF, 0xFF,
};
static char disp_on107[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x88, 0x1F, 0xFF, 0xFF,
};
static char disp_on108[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x89, 0x01, 0xFF, 0xFF,
};
static char disp_on109[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8A, 0x41, 0xFF, 0xFF,
};
static char disp_on110[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8B, 0x01, 0xFF, 0xFF,
};
static char disp_on111[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8C, 0x78, 0xFF, 0xFF,
};
static char disp_on112[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8D, 0x01, 0xFF, 0xFF,
};
static char disp_on113[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8E, 0xA5, 0xFF, 0xFF,
};
static char disp_on114[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8F, 0x01, 0xFF, 0xFF,
};
static char disp_on115[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x90, 0xEE, 0xFF, 0xFF,
};
static char disp_on116[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x91, 0x02, 0xFF, 0xFF,
};
static char disp_on117[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x92, 0x29, 0xFF, 0xFF,
};
static char disp_on118[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x93, 0x02, 0xFF, 0xFF,
};
static char disp_on119[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x94, 0x2A, 0xFF, 0xFF,
};
static char disp_on120[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x95, 0x02, 0xFF, 0xFF,
};
static char disp_on121[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x96, 0x5D, 0xFF, 0xFF,
};
static char disp_on122[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x97, 0x02, 0xFF, 0xFF,
};
static char disp_on123[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x98, 0x93, 0xFF, 0xFF,
};
static char disp_on124[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x99, 0x02, 0xFF, 0xFF,
};
static char disp_on125[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9A, 0xB8, 0xFF, 0xFF,
};
static char disp_on126[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9B, 0x02, 0xFF, 0xFF,
};
static char disp_on127[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9C, 0xE7, 0xFF, 0xFF,
};
static char disp_on128[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9D, 0x03, 0xFF, 0xFF,
};
static char disp_on129[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9E, 0x07, 0xFF, 0xFF,
};
static char disp_on130[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9F, 0x03, 0xFF, 0xFF,
};
static char disp_on131[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA0, 0x37, 0xFF, 0xFF,
};
static char disp_on132[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA2, 0x03, 0xFF, 0xFF,
};
static char disp_on133[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA3, 0x46, 0xFF, 0xFF,
};
static char disp_on134[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA4, 0x03, 0xFF, 0xFF,
};
static char disp_on135[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA5, 0x56, 0xFF, 0xFF,
};
static char disp_on136[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA6, 0x03, 0xFF, 0xFF,
};
static char disp_on137[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA7, 0x66, 0xFF, 0xFF,
};
static char disp_on138[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA9, 0x03, 0xFF, 0xFF,
};
static char disp_on139[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAA, 0x7A, 0xFF, 0xFF,
};
static char disp_on140[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAB, 0x03, 0xFF, 0xFF,
};
static char disp_on141[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAC, 0x93, 0xFF, 0xFF,
};
static char disp_on142[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAD, 0x03, 0xFF, 0xFF,
};
static char disp_on143[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAE, 0xA3, 0xFF, 0xFF,
};
static char disp_on144[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAF, 0x03, 0xFF, 0xFF,
};
static char disp_on145[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB0, 0xB4, 0xFF, 0xFF,
};
static char disp_on146[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB1, 0x03, 0xFF, 0xFF,
};
static char disp_on147[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB2, 0xCB, 0xFF, 0xFF,
};
static char disp_on148[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB3, 0x00, 0xFF, 0xFF,
};
static char disp_on149[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB4, 0x7D, 0xFF, 0xFF,
};
static char disp_on150[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB5, 0x00, 0xFF, 0xFF,
};
static char disp_on151[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB6, 0x8A, 0xFF, 0xFF,
};
static char disp_on152[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB7, 0x00, 0xFF, 0xFF,
};
static char disp_on153[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB8, 0x9C, 0xFF, 0xFF,
};
static char disp_on154[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB9, 0x00, 0xFF, 0xFF,
};
static char disp_on155[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBA, 0xB1, 0xFF, 0xFF,
};
static char disp_on156[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBB, 0x00, 0xFF, 0xFF,
};
static char disp_on157[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBC, 0xBF, 0xFF, 0xFF,
};
static char disp_on158[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBD, 0x00, 0xFF, 0xFF,
};
static char disp_on159[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBE, 0xCF, 0xFF, 0xFF,
};
static char disp_on160[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBF, 0x00, 0xFF, 0xFF,
};
static char disp_on161[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC0, 0xDD, 0xFF, 0xFF,
};
static char disp_on162[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC1, 0x00, 0xFF, 0xFF,
};
static char disp_on163[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC2, 0xE8, 0xFF, 0xFF,
};
static char disp_on164[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC3, 0x00, 0xFF, 0xFF,
};
static char disp_on165[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC4, 0xF2, 0xFF, 0xFF,
};
static char disp_on166[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC5, 0x01, 0xFF, 0xFF,
};
static char disp_on167[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC6, 0x1F, 0xFF, 0xFF,
};
static char disp_on168[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC7, 0x01, 0xFF, 0xFF,
};
static char disp_on169[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC8, 0x41, 0xFF, 0xFF,
};
static char disp_on170[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC9, 0x01, 0xFF, 0xFF,
};
static char disp_on171[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCA, 0x78, 0xFF, 0xFF,
};
static char disp_on172[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCB, 0x01, 0xFF, 0xFF,
};
static char disp_on173[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCC, 0xA5, 0xFF, 0xFF,
};
static char disp_on174[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCD, 0x01, 0xFF, 0xFF,
};
static char disp_on175[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCE, 0xEE, 0xFF, 0xFF,
};
static char disp_on176[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCF, 0x02, 0xFF, 0xFF,
};
static char disp_on177[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD0, 0x29, 0xFF, 0xFF,
};
static char disp_on178[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD1, 0x02, 0xFF, 0xFF,
};
static char disp_on179[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD2, 0x2A, 0xFF, 0xFF,
};
static char disp_on180[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD3, 0x02, 0xFF, 0xFF,
};
static char disp_on181[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD4, 0x5D, 0xFF, 0xFF,
};
static char disp_on182[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD5, 0x02, 0xFF, 0xFF,
};
static char disp_on183[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD6, 0x93, 0xFF, 0xFF,
};
static char disp_on184[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD7, 0x02, 0xFF, 0xFF,
};
static char disp_on185[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD8, 0xB8, 0xFF, 0xFF,
};
static char disp_on186[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD9, 0x02, 0xFF, 0xFF,
};
static char disp_on187[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDA, 0xE7, 0xFF, 0xFF,
};
static char disp_on188[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDB, 0x03, 0xFF, 0xFF,
};
static char disp_on189[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDC, 0x07, 0xFF, 0xFF,
};
static char disp_on190[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDD, 0x03, 0xFF, 0xFF,
};
static char disp_on191[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDE, 0x37, 0xFF, 0xFF,
};
static char disp_on192[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDF, 0x03, 0xFF, 0xFF,
};
static char disp_on193[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE0, 0x46, 0xFF, 0xFF,
};
static char disp_on194[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE1, 0x03, 0xFF, 0xFF,
};
static char disp_on195[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE2, 0x56, 0xFF, 0xFF,
};
static char disp_on196[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE3, 0x03, 0xFF, 0xFF,
};
static char disp_on197[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE4, 0x66, 0xFF, 0xFF,
};
static char disp_on198[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE5, 0x03, 0xFF, 0xFF,
};
static char disp_on199[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE6, 0x7A, 0xFF, 0xFF,
};
static char disp_on200[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE7, 0x03, 0xFF, 0xFF,
};
static char disp_on201[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE8, 0x93, 0xFF, 0xFF,
};
static char disp_on202[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE9, 0x03, 0xFF, 0xFF,
};
static char disp_on203[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xEA, 0xA3, 0xFF, 0xFF,
};
static char disp_on204[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xEB, 0x03, 0xFF, 0xFF,
};
static char disp_on205[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xEC, 0xB4, 0xFF, 0xFF,
};
static char disp_on206[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xED, 0x03, 0xFF, 0xFF,
};
static char disp_on207[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xEE, 0xCB, 0xFF, 0xFF,
};
static char disp_on208[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xEF, 0x00, 0xFF, 0xFF,
};
static char disp_on209[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF0, 0xED, 0xFF, 0xFF,
};
static char disp_on210[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF1, 0x00, 0xFF, 0xFF,
};
static char disp_on211[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF2, 0xF3, 0xFF, 0xFF,
};
static char disp_on212[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF3, 0x00, 0xFF, 0xFF,
};
static char disp_on213[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF4, 0xFE, 0xFF, 0xFF,
};
static char disp_on214[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF5, 0x01, 0xFF, 0xFF,
};
static char disp_on215[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF6, 0x09, 0xFF, 0xFF,
};
static char disp_on216[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF7, 0x01, 0xFF, 0xFF,
};
static char disp_on217[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF8, 0x13, 0xFF, 0xFF,
};
static char disp_on218[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xF9, 0x01, 0xFF, 0xFF,
};
static char disp_on219[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFA, 0x1D, 0xFF, 0xFF,
};
static char disp_on220[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x02, 0xFF, 0xFF,
};
static char disp_on221[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on222[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x00, 0x01, 0xFF, 0xFF,
};
static char disp_on223[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x01, 0x26, 0xFF, 0xFF,
};
static char disp_on224[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x02, 0x01, 0xFF, 0xFF,
};
static char disp_on225[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x03, 0x2F, 0xFF, 0xFF,
};
static char disp_on226[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x04, 0x01, 0xFF, 0xFF,
};
static char disp_on227[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x05, 0x37, 0xFF, 0xFF,
};
static char disp_on228[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x06, 0x01, 0xFF, 0xFF,
};
static char disp_on229[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x07, 0x56, 0xFF, 0xFF,
};
static char disp_on230[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x08, 0x01, 0xFF, 0xFF,
};
static char disp_on231[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x09, 0x70, 0xFF, 0xFF,
};
static char disp_on232[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0A, 0x01, 0xFF, 0xFF,
};
static char disp_on233[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0B, 0x9D, 0xFF, 0xFF,
};
static char disp_on234[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0C, 0x01, 0xFF, 0xFF,
};
static char disp_on235[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0D, 0xC2, 0xFF, 0xFF,
};
static char disp_on236[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0E, 0x01, 0xFF, 0xFF,
};
static char disp_on237[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x0F, 0xFF, 0xFF, 0xFF,
};
static char disp_on238[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x10, 0x02, 0xFF, 0xFF,
};
static char disp_on239[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x11, 0x31, 0xFF, 0xFF,
};
static char disp_on240[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x12, 0x02, 0xFF, 0xFF,
};
static char disp_on241[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x13, 0x32, 0xFF, 0xFF,
};
static char disp_on242[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x14, 0x02, 0xFF, 0xFF,
};
static char disp_on243[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x15, 0x60, 0xFF, 0xFF,
};
static char disp_on244[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x16, 0x02, 0xFF, 0xFF,
};
static char disp_on245[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x17, 0x94, 0xFF, 0xFF,
};
static char disp_on246[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x18, 0x02, 0xFF, 0xFF,
};
static char disp_on247[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x19, 0xB5, 0xFF, 0xFF,
};
static char disp_on248[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1A, 0x02, 0xFF, 0xFF,
};
static char disp_on249[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1B, 0xE3, 0xFF, 0xFF,
};
static char disp_on250[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1C, 0x03, 0xFF, 0xFF,
};
static char disp_on251[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1D, 0x03, 0xFF, 0xFF,
};
static char disp_on252[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1E, 0x03, 0xFF, 0xFF,
};
static char disp_on253[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x1F, 0x2D, 0xFF, 0xFF,
};
static char disp_on254[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x20, 0x03, 0xFF, 0xFF,
};
static char disp_on255[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x21, 0x3A, 0xFF, 0xFF,
};
static char disp_on256[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x22, 0x03, 0xFF, 0xFF,
};
static char disp_on257[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x23, 0x48, 0xFF, 0xFF,
};
static char disp_on258[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x24, 0x03, 0xFF, 0xFF,
};
static char disp_on259[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x25, 0x57, 0xFF, 0xFF,
};
static char disp_on260[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x26, 0x03, 0xFF, 0xFF,
};
static char disp_on261[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x27, 0x68, 0xFF, 0xFF,
};
static char disp_on262[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x28, 0x03, 0xFF, 0xFF,
};
static char disp_on263[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x29, 0x7B, 0xFF, 0xFF,
};
static char disp_on264[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x2A, 0x03, 0xFF, 0xFF,
};
static char disp_on265[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x2B, 0x90, 0xFF, 0xFF,
};
static char disp_on266[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x2D, 0x03, 0xFF, 0xFF,
};
static char disp_on267[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x2F, 0xA0, 0xFF, 0xFF,
};
static char disp_on268[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x30, 0x03, 0xFF, 0xFF,
};
static char disp_on269[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x31, 0xCB, 0xFF, 0xFF,
};
static char disp_on270[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x32, 0x00, 0xFF, 0xFF,
};
static char disp_on271[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x33, 0xED, 0xFF, 0xFF,
};
static char disp_on272[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x34, 0x00, 0xFF, 0xFF,
};
static char disp_on273[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x35, 0xF3, 0xFF, 0xFF,
};
static char disp_on274[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x36, 0x00, 0xFF, 0xFF,
};
static char disp_on275[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x37, 0xFE, 0xFF, 0xFF,
};
static char disp_on276[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x38, 0x01, 0xFF, 0xFF,
};
static char disp_on277[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x39, 0x09, 0xFF, 0xFF,
};
static char disp_on278[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x3A, 0x01, 0xFF, 0xFF,
};
static char disp_on279[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x3B, 0x13, 0xFF, 0xFF,
};
static char disp_on280[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x3D, 0x01, 0xFF, 0xFF,
};
static char disp_on281[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x3F, 0x1D, 0xFF, 0xFF,
};
static char disp_on282[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x40, 0x01, 0xFF, 0xFF,
};
static char disp_on283[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x41, 0x26, 0xFF, 0xFF,
};
static char disp_on284[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x42, 0x01, 0xFF, 0xFF,
};
static char disp_on285[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x43, 0x2F, 0xFF, 0xFF,
};
static char disp_on286[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x44, 0x01, 0xFF, 0xFF,
};
static char disp_on287[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x45, 0x37, 0xFF, 0xFF,
};
static char disp_on288[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x46, 0x01, 0xFF, 0xFF,
};
static char disp_on289[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x47, 0x56, 0xFF, 0xFF,
};
static char disp_on290[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x48, 0x01, 0xFF, 0xFF,
};
static char disp_on291[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x49, 0x70, 0xFF, 0xFF,
};
static char disp_on292[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4A, 0x01, 0xFF, 0xFF,
};
static char disp_on293[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4B, 0x9D, 0xFF, 0xFF,
};
static char disp_on294[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4C, 0x01, 0xFF, 0xFF,
};
static char disp_on295[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4D, 0xC2, 0xFF, 0xFF,
};
static char disp_on296[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4E, 0x01, 0xFF, 0xFF,
};
static char disp_on297[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x4F, 0xFF, 0xFF, 0xFF,
};
static char disp_on298[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x50, 0x02, 0xFF, 0xFF,
};
static char disp_on299[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x51, 0x31, 0xFF, 0xFF,
};
static char disp_on300[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x52, 0x02, 0xFF, 0xFF,
};
static char disp_on301[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x53, 0x32, 0xFF, 0xFF,
};
static char disp_on302[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x54, 0x02, 0xFF, 0xFF,
};
static char disp_on303[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x55, 0x60, 0xFF, 0xFF,
};
static char disp_on304[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x56, 0x02, 0xFF, 0xFF,
};
static char disp_on305[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x58, 0x94, 0xFF, 0xFF,
};
static char disp_on306[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x59, 0x02, 0xFF, 0xFF,
};
static char disp_on307[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5A, 0xB5, 0xFF, 0xFF,
};
static char disp_on308[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5B, 0x02, 0xFF, 0xFF,
};
static char disp_on309[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5C, 0xE3, 0xFF, 0xFF,
};
static char disp_on310[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5D, 0x03, 0xFF, 0xFF,
};
static char disp_on311[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5E, 0x03, 0xFF, 0xFF,
};
static char disp_on312[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x5F, 0x03, 0xFF, 0xFF,
};
static char disp_on313[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x60, 0x2D, 0xFF, 0xFF,
};
static char disp_on314[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x61, 0x03, 0xFF, 0xFF,
};
static char disp_on315[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x62, 0x3A, 0xFF, 0xFF,
};
static char disp_on316[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x63, 0x03, 0xFF, 0xFF,
};
static char disp_on317[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x64, 0x48, 0xFF, 0xFF,
};
static char disp_on318[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x65, 0x03, 0xFF, 0xFF,
};
static char disp_on319[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x66, 0x57, 0xFF, 0xFF,
};
static char disp_on320[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x67, 0x03, 0xFF, 0xFF,
};
static char disp_on321[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x68, 0x68, 0xFF, 0xFF,
};
static char disp_on322[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x69, 0x03, 0xFF, 0xFF,
};
static char disp_on323[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6A, 0x7B, 0xFF, 0xFF,
};
static char disp_on324[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6B, 0x03, 0xFF, 0xFF,
};
static char disp_on325[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6C, 0x90, 0xFF, 0xFF,
};
static char disp_on326[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6D, 0x03, 0xFF, 0xFF,
};
static char disp_on327[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6E, 0xA0, 0xFF, 0xFF,
};
static char disp_on328[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6F, 0x03, 0xFF, 0xFF,
};
static char disp_on329[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x70, 0xCB, 0xFF, 0xFF,
};
static char disp_on330[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x71, 0x00, 0xFF, 0xFF,
};
static char disp_on331[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x72, 0x19, 0xFF, 0xFF,
};
static char disp_on332[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x73, 0x00, 0xFF, 0xFF,
};
static char disp_on333[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x74, 0x36, 0xFF, 0xFF,
};
static char disp_on334[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x75, 0x00, 0xFF, 0xFF,
};
static char disp_on335[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x76, 0x55, 0xFF, 0xFF,
};
static char disp_on336[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x77, 0x00, 0xFF, 0xFF,
};
static char disp_on337[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x78, 0x70, 0xFF, 0xFF,
};
static char disp_on338[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x79, 0x00, 0xFF, 0xFF,
};
static char disp_on339[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7A, 0x83, 0xFF, 0xFF,
};
static char disp_on340[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7B, 0x00, 0xFF, 0xFF,
};
static char disp_on341[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7C, 0x99, 0xFF, 0xFF,
};
static char disp_on342[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7D, 0x00, 0xFF, 0xFF,
};
static char disp_on343[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7E, 0xA8, 0xFF, 0xFF,
};
static char disp_on344[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x7F, 0x00, 0xFF, 0xFF,
};
static char disp_on345[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x80, 0xB7, 0xFF, 0xFF,
};
static char disp_on346[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x81, 0x00, 0xFF, 0xFF,
};
static char disp_on347[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x82, 0xC5, 0xFF, 0xFF,
};
static char disp_on348[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x83, 0x00, 0xFF, 0xFF,
};
static char disp_on349[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x84, 0xF7, 0xFF, 0xFF,
};
static char disp_on350[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x85, 0x01, 0xFF, 0xFF,
};
static char disp_on351[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x86, 0x1E, 0xFF, 0xFF,
};
static char disp_on352[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x87, 0x01, 0xFF, 0xFF,
};
static char disp_on353[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x88, 0x60, 0xFF, 0xFF,
};
static char disp_on354[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x89, 0x01, 0xFF, 0xFF,
};
static char disp_on355[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8A, 0x95, 0xFF, 0xFF,
};
static char disp_on356[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8B, 0x01, 0xFF, 0xFF,
};
static char disp_on357[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8C, 0xE1, 0xFF, 0xFF,
};
static char disp_on358[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8D, 0x02, 0xFF, 0xFF,
};
static char disp_on359[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8E, 0x20, 0xFF, 0xFF,
};
static char disp_on360[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x8F, 0x02, 0xFF, 0xFF,
};
static char disp_on361[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x90, 0x23, 0xFF, 0xFF,
};
static char disp_on362[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x91, 0x02, 0xFF, 0xFF,
};
static char disp_on363[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x92, 0x59, 0xFF, 0xFF,
};
static char disp_on364[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x93, 0x02, 0xFF, 0xFF,
};
static char disp_on365[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x94, 0x94, 0xFF, 0xFF,
};
static char disp_on366[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x95, 0x02, 0xFF, 0xFF,
};
static char disp_on367[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x96, 0xB4, 0xFF, 0xFF,
};
static char disp_on368[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x97, 0x02, 0xFF, 0xFF,
};
static char disp_on369[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x98, 0xE1, 0xFF, 0xFF,
};
static char disp_on370[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x99, 0x03, 0xFF, 0xFF,
};
static char disp_on371[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9A, 0x01, 0xFF, 0xFF,
};
static char disp_on372[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9B, 0x03, 0xFF, 0xFF,
};
static char disp_on373[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9C, 0x28, 0xFF, 0xFF,
};
static char disp_on374[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9D, 0x03, 0xFF, 0xFF,
};
static char disp_on375[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9E, 0x30, 0xFF, 0xFF,
};
static char disp_on376[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x9F, 0x03, 0xFF, 0xFF,
};
static char disp_on377[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA0, 0x37, 0xFF, 0xFF,
};
static char disp_on378[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA2, 0x03, 0xFF, 0xFF,
};
static char disp_on379[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA3, 0x3B, 0xFF, 0xFF,
};
static char disp_on380[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA4, 0x03, 0xFF, 0xFF,
};
static char disp_on381[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA5, 0x40, 0xFF, 0xFF,
};
static char disp_on382[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA6, 0x03, 0xFF, 0xFF,
};
static char disp_on383[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA7, 0x50, 0xFF, 0xFF,
};
static char disp_on384[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xA9, 0x03, 0xFF, 0xFF,
};
static char disp_on385[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAA, 0x6D, 0xFF, 0xFF,
};
static char disp_on386[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAB, 0x03, 0xFF, 0xFF,
};
static char disp_on387[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAC, 0x80, 0xFF, 0xFF,
};
static char disp_on388[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAD, 0x03, 0xFF, 0xFF,
};
static char disp_on389[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAE, 0xCB, 0xFF, 0xFF,
};
static char disp_on390[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xAF, 0x00, 0xFF, 0xFF,
};
static char disp_on391[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB0, 0x19, 0xFF, 0xFF,
};
static char disp_on392[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB1, 0x00, 0xFF, 0xFF,
};
static char disp_on393[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB2, 0x36, 0xFF, 0xFF,
};
static char disp_on394[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB3, 0x00, 0xFF, 0xFF,
};
static char disp_on395[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB4, 0x55, 0xFF, 0xFF,
};
static char disp_on396[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB5, 0x00, 0xFF, 0xFF,
};
static char disp_on397[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB6, 0x70, 0xFF, 0xFF,
};
static char disp_on398[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB7, 0x00, 0xFF, 0xFF,
};
static char disp_on399[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB8, 0x83, 0xFF, 0xFF,
};
static char disp_on400[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xB9, 0x00, 0xFF, 0xFF,
};
static char disp_on401[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBA, 0x99, 0xFF, 0xFF,
};
static char disp_on402[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBB, 0x00, 0xFF, 0xFF,
};
static char disp_on403[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBC, 0xA8, 0xFF, 0xFF,
};
static char disp_on404[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBD, 0x00, 0xFF, 0xFF,
};
static char disp_on405[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBE, 0xB7, 0xFF, 0xFF,
};
static char disp_on406[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xBF, 0x00, 0xFF, 0xFF,
};
static char disp_on407[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC0, 0xC5, 0xFF, 0xFF,
};
static char disp_on408[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC1, 0x00, 0xFF, 0xFF,
};
static char disp_on409[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC2, 0xF7, 0xFF, 0xFF,
};
static char disp_on410[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC3, 0x01, 0xFF, 0xFF,
};
static char disp_on411[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC4, 0x1E, 0xFF, 0xFF,
};
static char disp_on412[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC5, 0x01, 0xFF, 0xFF,
};
static char disp_on413[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC6, 0x60, 0xFF, 0xFF,
};
static char disp_on414[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC7, 0x01, 0xFF, 0xFF,
};
static char disp_on415[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC8, 0x95, 0xFF, 0xFF,
};
static char disp_on416[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xC9, 0x01, 0xFF, 0xFF,
};
static char disp_on417[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCA, 0xE1, 0xFF, 0xFF,
};
static char disp_on418[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCB, 0x02, 0xFF, 0xFF,
};
static char disp_on419[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCC, 0x20, 0xFF, 0xFF,
};
static char disp_on420[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCD, 0x02, 0xFF, 0xFF,
};
static char disp_on421[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCE, 0x23, 0xFF, 0xFF,
};
static char disp_on422[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xCF, 0x02, 0xFF, 0xFF,
};
static char disp_on423[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD0, 0x59, 0xFF, 0xFF,
};
static char disp_on424[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD1, 0x02, 0xFF, 0xFF,
};
static char disp_on425[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD2, 0x94, 0xFF, 0xFF,
};
static char disp_on426[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD3, 0x02, 0xFF, 0xFF,
};
static char disp_on427[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD4, 0xB4, 0xFF, 0xFF,
};
static char disp_on428[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD5, 0x02, 0xFF, 0xFF,
};
static char disp_on429[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD6, 0xE1, 0xFF, 0xFF,
};
static char disp_on430[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD7, 0x03, 0xFF, 0xFF,
};
static char disp_on431[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD8, 0x01, 0xFF, 0xFF,
};
static char disp_on432[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xD9, 0x03, 0xFF, 0xFF,
};
static char disp_on433[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDA, 0x28, 0xFF, 0xFF,
};
static char disp_on434[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDB, 0x03, 0xFF, 0xFF,
};
static char disp_on435[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDC, 0x30, 0xFF, 0xFF,
};
static char disp_on436[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDD, 0x03, 0xFF, 0xFF,
};
static char disp_on437[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDE, 0x37, 0xFF, 0xFF,
};
static char disp_on438[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xDF, 0x03, 0xFF, 0xFF,
};
static char disp_on439[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE0, 0x3B, 0xFF, 0xFF,
};
static char disp_on440[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE1, 0x03, 0xFF, 0xFF,
};
static char disp_on441[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE2, 0x40, 0xFF, 0xFF,
};
static char disp_on442[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE3, 0x03, 0xFF, 0xFF,
};
static char disp_on443[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE4, 0x50, 0xFF, 0xFF,
};
static char disp_on444[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE5, 0x03, 0xFF, 0xFF,
};
static char disp_on445[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE6, 0x6D, 0xFF, 0xFF,
};
static char disp_on446[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE7, 0x03, 0xFF, 0xFF,
};
static char disp_on447[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE8, 0x80, 0xFF, 0xFF,
};
static char disp_on448[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xE9, 0x03, 0xFF, 0xFF,
};
static char disp_on449[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xEA, 0xCB, 0xFF, 0xFF,
};
static char disp_on450[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x01, 0xFF, 0xFF,
};
static char disp_on451[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on452[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x02, 0xFF, 0xFF,
};
static char disp_on453[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on454[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x04, 0xFF, 0xFF,
};
static char disp_on455[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFB, 0x01, 0xFF, 0xFF,
};
static char disp_on456[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x00, 0xFF, 0xFF,
};
static char disp_on457[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x11, 0x00, 0xFF, 0xFF,
};
static char disp_on458[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0xEE, 0xFF, 0xFF,
};
static char disp_on459[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x12, 0x50, 0xFF, 0xFF,
};
static char disp_on460[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x13, 0x02, 0xFF, 0xFF,
};
static char disp_on461[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x6A, 0x60, 0xFF, 0xFF,
};
static char disp_on462[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0xFF, 0x00, 0xFF, 0xFF,
};
static char disp_on463[8] = {
	0x02, 0x00, 0x39, 0xc0,
	0x29, 0x00, 0xFF, 0xFF,
};

static struct mipi_dsi_cmd nt35590_panel_video_mode_cmds[] = {
	{sizeof(disp_on0), (char *)disp_on0},
	{sizeof(disp_on1), (char *)disp_on1},
	{sizeof(disp_on2), (char *)disp_on2},
	{sizeof(disp_on3), (char *)disp_on3},
	{sizeof(lane), (char *)lane},
	{sizeof(video_mode), (char *)video_mode},
	{sizeof(disp_on6), (char *)disp_on6},
	{sizeof(disp_on7), (char *)disp_on7},
	{sizeof(disp_on8), (char *)disp_on8},
	{sizeof(disp_on9), (char *)disp_on9},
	{sizeof(disp_on10), (char *)disp_on10},
	{sizeof(disp_on11), (char *)disp_on11},
	{sizeof(disp_on12), (char *)disp_on12},
	{sizeof(disp_on13), (char *)disp_on13},
	{sizeof(disp_on14), (char *)disp_on14},
	{sizeof(disp_on15), (char *)disp_on15},
	{sizeof(disp_on16), (char *)disp_on16},
	{sizeof(disp_on17), (char *)disp_on17},
	{sizeof(disp_on18), (char *)disp_on18},
	{sizeof(disp_on19), (char *)disp_on19},
	{sizeof(disp_on20), (char *)disp_on20},
	{sizeof(disp_on21), (char *)disp_on21},
	{sizeof(disp_on22), (char *)disp_on22},
	{sizeof(disp_on23), (char *)disp_on23},
	{sizeof(disp_on24), (char *)disp_on24},
	{sizeof(disp_on25), (char *)disp_on25},
	{sizeof(disp_on26), (char *)disp_on26},
	{sizeof(disp_on27), (char *)disp_on27},
	{sizeof(disp_on28), (char *)disp_on28},
	{sizeof(disp_on29), (char *)disp_on29},
	{sizeof(disp_on30), (char *)disp_on30},
	{sizeof(disp_on31), (char *)disp_on31},
	{sizeof(disp_on32), (char *)disp_on32},
	{sizeof(disp_on33), (char *)disp_on33},
	{sizeof(disp_on34), (char *)disp_on34},
	{sizeof(disp_on35), (char *)disp_on35},
	{sizeof(disp_on36), (char *)disp_on36},
	{sizeof(disp_on37), (char *)disp_on37},
	{sizeof(disp_on38), (char *)disp_on38},
	{sizeof(disp_on39), (char *)disp_on39},
	{sizeof(disp_on40), (char *)disp_on40},
	{sizeof(disp_on41), (char *)disp_on41},
	{sizeof(disp_on42), (char *)disp_on42},
	{sizeof(disp_on43), (char *)disp_on43},
	{sizeof(disp_on44), (char *)disp_on44},
	{sizeof(disp_on45), (char *)disp_on45},
	{sizeof(disp_on46), (char *)disp_on46},
	{sizeof(disp_on47), (char *)disp_on47},
	{sizeof(disp_on48), (char *)disp_on48},
	{sizeof(disp_on49), (char *)disp_on49},
	{sizeof(disp_on50), (char *)disp_on50},
	{sizeof(disp_on51), (char *)disp_on51},
	{sizeof(disp_on52), (char *)disp_on52},
	{sizeof(disp_on53), (char *)disp_on53},
	{sizeof(disp_on54), (char *)disp_on54},
	{sizeof(disp_on55), (char *)disp_on55},
	{sizeof(disp_on56), (char *)disp_on56},
	{sizeof(disp_on57), (char *)disp_on57},
	{sizeof(disp_on58), (char *)disp_on58},
	{sizeof(disp_on59), (char *)disp_on59},
	{sizeof(disp_on60), (char *)disp_on60},
	{sizeof(disp_on61), (char *)disp_on61},
	{sizeof(disp_on62), (char *)disp_on62},
	{sizeof(disp_on63), (char *)disp_on63},
	{sizeof(disp_on64), (char *)disp_on64},
	{sizeof(disp_on65), (char *)disp_on65},
	{sizeof(disp_on66), (char *)disp_on66},
	{sizeof(disp_on67), (char *)disp_on67},
	{sizeof(disp_on68), (char *)disp_on68},
	{sizeof(disp_on69), (char *)disp_on69},
	{sizeof(disp_on70), (char *)disp_on70},
	{sizeof(disp_on71), (char *)disp_on71},
	{sizeof(disp_on72), (char *)disp_on72},
	{sizeof(disp_on73), (char *)disp_on73},
	{sizeof(disp_on74), (char *)disp_on74},
	{sizeof(disp_on75), (char *)disp_on75},
	{sizeof(disp_on76), (char *)disp_on76},
	{sizeof(disp_on77), (char *)disp_on77},
	{sizeof(disp_on78), (char *)disp_on78},
	{sizeof(disp_on79), (char *)disp_on79},
	{sizeof(disp_on80), (char *)disp_on80},
	{sizeof(disp_on81), (char *)disp_on81},
	{sizeof(disp_on82), (char *)disp_on82},
	{sizeof(disp_on83), (char *)disp_on83},
	{sizeof(disp_on84), (char *)disp_on84},
	{sizeof(disp_on85), (char *)disp_on85},
	{sizeof(disp_on86), (char *)disp_on86},
	{sizeof(disp_on87), (char *)disp_on87},
	{sizeof(disp_on88), (char *)disp_on88},
	{sizeof(disp_on89), (char *)disp_on89},
	{sizeof(disp_on90), (char *)disp_on90},
	{sizeof(disp_on91), (char *)disp_on91},
	{sizeof(disp_on92), (char *)disp_on92},
	{sizeof(disp_on93), (char *)disp_on93},
	{sizeof(disp_on94), (char *)disp_on94},
	{sizeof(disp_on95), (char *)disp_on95},
	{sizeof(disp_on96), (char *)disp_on96},
	{sizeof(disp_on97), (char *)disp_on97},
	{sizeof(disp_on98), (char *)disp_on98},
	{sizeof(disp_on99), (char *)disp_on99},
	{sizeof(disp_on100), (char *)disp_on100},
	{sizeof(disp_on101), (char *)disp_on101},
	{sizeof(disp_on102), (char *)disp_on102},
	{sizeof(disp_on103), (char *)disp_on103},
	{sizeof(disp_on104), (char *)disp_on104},
	{sizeof(disp_on105), (char *)disp_on105},
	{sizeof(disp_on106), (char *)disp_on106},
	{sizeof(disp_on107), (char *)disp_on107},
	{sizeof(disp_on108), (char *)disp_on108},
	{sizeof(disp_on109), (char *)disp_on109},
	{sizeof(disp_on110), (char *)disp_on110},
	{sizeof(disp_on111), (char *)disp_on111},
	{sizeof(disp_on112), (char *)disp_on112},
	{sizeof(disp_on113), (char *)disp_on113},
	{sizeof(disp_on114), (char *)disp_on114},
	{sizeof(disp_on115), (char *)disp_on115},
	{sizeof(disp_on116), (char *)disp_on116},
	{sizeof(disp_on117), (char *)disp_on117},
	{sizeof(disp_on118), (char *)disp_on118},
	{sizeof(disp_on119), (char *)disp_on119},
	{sizeof(disp_on120), (char *)disp_on120},
	{sizeof(disp_on121), (char *)disp_on121},
	{sizeof(disp_on122), (char *)disp_on122},
	{sizeof(disp_on123), (char *)disp_on123},
	{sizeof(disp_on124), (char *)disp_on124},
	{sizeof(disp_on125), (char *)disp_on125},
	{sizeof(disp_on126), (char *)disp_on126},
	{sizeof(disp_on127), (char *)disp_on127},
	{sizeof(disp_on128), (char *)disp_on128},
	{sizeof(disp_on129), (char *)disp_on129},
	{sizeof(disp_on130), (char *)disp_on130},
	{sizeof(disp_on131), (char *)disp_on131},
	{sizeof(disp_on132), (char *)disp_on132},
	{sizeof(disp_on133), (char *)disp_on133},
	{sizeof(disp_on134), (char *)disp_on134},
	{sizeof(disp_on135), (char *)disp_on135},
	{sizeof(disp_on136), (char *)disp_on136},
	{sizeof(disp_on137), (char *)disp_on137},
	{sizeof(disp_on138), (char *)disp_on138},
	{sizeof(disp_on139), (char *)disp_on139},
	{sizeof(disp_on140), (char *)disp_on140},
	{sizeof(disp_on141), (char *)disp_on141},
	{sizeof(disp_on142), (char *)disp_on142},
	{sizeof(disp_on143), (char *)disp_on143},
	{sizeof(disp_on144), (char *)disp_on144},
	{sizeof(disp_on145), (char *)disp_on145},
	{sizeof(disp_on146), (char *)disp_on146},
	{sizeof(disp_on147), (char *)disp_on147},
	{sizeof(disp_on148), (char *)disp_on148},
	{sizeof(disp_on149), (char *)disp_on149},
	{sizeof(disp_on150), (char *)disp_on150},
	{sizeof(disp_on151), (char *)disp_on151},
	{sizeof(disp_on152), (char *)disp_on152},
	{sizeof(disp_on153), (char *)disp_on153},
	{sizeof(disp_on154), (char *)disp_on154},
	{sizeof(disp_on155), (char *)disp_on155},
	{sizeof(disp_on156), (char *)disp_on156},
	{sizeof(disp_on157), (char *)disp_on157},
	{sizeof(disp_on158), (char *)disp_on158},
	{sizeof(disp_on159), (char *)disp_on159},
	{sizeof(disp_on160), (char *)disp_on150},
	{sizeof(disp_on161), (char *)disp_on161},
	{sizeof(disp_on162), (char *)disp_on162},
	{sizeof(disp_on163), (char *)disp_on163},
	{sizeof(disp_on164), (char *)disp_on164},
	{sizeof(disp_on165), (char *)disp_on165},
	{sizeof(disp_on166), (char *)disp_on166},
	{sizeof(disp_on167), (char *)disp_on167},
	{sizeof(disp_on168), (char *)disp_on168},
	{sizeof(disp_on169), (char *)disp_on169},
	{sizeof(disp_on170), (char *)disp_on170},
	{sizeof(disp_on171), (char *)disp_on171},
	{sizeof(disp_on172), (char *)disp_on172},
	{sizeof(disp_on173), (char *)disp_on173},
	{sizeof(disp_on174), (char *)disp_on174},
	{sizeof(disp_on175), (char *)disp_on175},
	{sizeof(disp_on176), (char *)disp_on176},
	{sizeof(disp_on177), (char *)disp_on177},
	{sizeof(disp_on178), (char *)disp_on178},
	{sizeof(disp_on179), (char *)disp_on179},
	{sizeof(disp_on180), (char *)disp_on180},
	{sizeof(disp_on181), (char *)disp_on181},
	{sizeof(disp_on182), (char *)disp_on182},
	{sizeof(disp_on183), (char *)disp_on183},
	{sizeof(disp_on184), (char *)disp_on184},
	{sizeof(disp_on185), (char *)disp_on185},
	{sizeof(disp_on186), (char *)disp_on186},
	{sizeof(disp_on187), (char *)disp_on187},
	{sizeof(disp_on188), (char *)disp_on188},
	{sizeof(disp_on189), (char *)disp_on189},
	{sizeof(disp_on190), (char *)disp_on190},
	{sizeof(disp_on191), (char *)disp_on191},
	{sizeof(disp_on192), (char *)disp_on192},
	{sizeof(disp_on193), (char *)disp_on193},
	{sizeof(disp_on194), (char *)disp_on194},
	{sizeof(disp_on195), (char *)disp_on195},
	{sizeof(disp_on196), (char *)disp_on196},
	{sizeof(disp_on197), (char *)disp_on197},
	{sizeof(disp_on198), (char *)disp_on198},
	{sizeof(disp_on199), (char *)disp_on199},
	{sizeof(disp_on200), (char *)disp_on200},
	{sizeof(disp_on201), (char *)disp_on201},
	{sizeof(disp_on202), (char *)disp_on202},
	{sizeof(disp_on203), (char *)disp_on203},
	{sizeof(disp_on204), (char *)disp_on204},
	{sizeof(disp_on205), (char *)disp_on205},
	{sizeof(disp_on206), (char *)disp_on206},
	{sizeof(disp_on207), (char *)disp_on207},
	{sizeof(disp_on208), (char *)disp_on208},
	{sizeof(disp_on209), (char *)disp_on209},
	{sizeof(disp_on210), (char *)disp_on210},
	{sizeof(disp_on211), (char *)disp_on211},
	{sizeof(disp_on212), (char *)disp_on212},
	{sizeof(disp_on213), (char *)disp_on213},
	{sizeof(disp_on214), (char *)disp_on214},
	{sizeof(disp_on215), (char *)disp_on215},
	{sizeof(disp_on216), (char *)disp_on216},
	{sizeof(disp_on217), (char *)disp_on217},
	{sizeof(disp_on218), (char *)disp_on218},
	{sizeof(disp_on219), (char *)disp_on219},
	{sizeof(disp_on220), (char *)disp_on220},
	{sizeof(disp_on221), (char *)disp_on221},
	{sizeof(disp_on222), (char *)disp_on222},
	{sizeof(disp_on223), (char *)disp_on223},
	{sizeof(disp_on224), (char *)disp_on224},
	{sizeof(disp_on225), (char *)disp_on225},
	{sizeof(disp_on226), (char *)disp_on226},
	{sizeof(disp_on227), (char *)disp_on227},
	{sizeof(disp_on228), (char *)disp_on228},
	{sizeof(disp_on229), (char *)disp_on229},
	{sizeof(disp_on230), (char *)disp_on230},
	{sizeof(disp_on231), (char *)disp_on231},
	{sizeof(disp_on232), (char *)disp_on232},
	{sizeof(disp_on233), (char *)disp_on233},
	{sizeof(disp_on234), (char *)disp_on234},
	{sizeof(disp_on235), (char *)disp_on235},
	{sizeof(disp_on236), (char *)disp_on236},
	{sizeof(disp_on237), (char *)disp_on237},
	{sizeof(disp_on238), (char *)disp_on238},
	{sizeof(disp_on239), (char *)disp_on239},
	{sizeof(disp_on240), (char *)disp_on240},
	{sizeof(disp_on241), (char *)disp_on241},
	{sizeof(disp_on242), (char *)disp_on242},
	{sizeof(disp_on243), (char *)disp_on243},
	{sizeof(disp_on244), (char *)disp_on244},
	{sizeof(disp_on245), (char *)disp_on245},
	{sizeof(disp_on246), (char *)disp_on246},
	{sizeof(disp_on247), (char *)disp_on247},
	{sizeof(disp_on248), (char *)disp_on248},
	{sizeof(disp_on249), (char *)disp_on249},
	{sizeof(disp_on250), (char *)disp_on250},
	{sizeof(disp_on251), (char *)disp_on251},
	{sizeof(disp_on252), (char *)disp_on252},
	{sizeof(disp_on253), (char *)disp_on253},
	{sizeof(disp_on254), (char *)disp_on254},
	{sizeof(disp_on255), (char *)disp_on255},
	{sizeof(disp_on256), (char *)disp_on256},
	{sizeof(disp_on257), (char *)disp_on257},
	{sizeof(disp_on258), (char *)disp_on258},
	{sizeof(disp_on259), (char *)disp_on259},
	{sizeof(disp_on260), (char *)disp_on260},
	{sizeof(disp_on261), (char *)disp_on261},
	{sizeof(disp_on262), (char *)disp_on262},
	{sizeof(disp_on263), (char *)disp_on263},
	{sizeof(disp_on264), (char *)disp_on264},
	{sizeof(disp_on265), (char *)disp_on265},
	{sizeof(disp_on266), (char *)disp_on266},
	{sizeof(disp_on267), (char *)disp_on267},
	{sizeof(disp_on268), (char *)disp_on268},
	{sizeof(disp_on269), (char *)disp_on269},
	{sizeof(disp_on270), (char *)disp_on270},
	{sizeof(disp_on271), (char *)disp_on271},
	{sizeof(disp_on272), (char *)disp_on272},
	{sizeof(disp_on273), (char *)disp_on273},
	{sizeof(disp_on274), (char *)disp_on274},
	{sizeof(disp_on275), (char *)disp_on275},
	{sizeof(disp_on276), (char *)disp_on276},
	{sizeof(disp_on277), (char *)disp_on277},
	{sizeof(disp_on278), (char *)disp_on278},
	{sizeof(disp_on279), (char *)disp_on279},
	{sizeof(disp_on280), (char *)disp_on280},
	{sizeof(disp_on281), (char *)disp_on281},
	{sizeof(disp_on282), (char *)disp_on282},
	{sizeof(disp_on283), (char *)disp_on283},
	{sizeof(disp_on284), (char *)disp_on284},
	{sizeof(disp_on285), (char *)disp_on285},
	{sizeof(disp_on286), (char *)disp_on286},
	{sizeof(disp_on287), (char *)disp_on287},
	{sizeof(disp_on288), (char *)disp_on288},
	{sizeof(disp_on289), (char *)disp_on289},
	{sizeof(disp_on290), (char *)disp_on290},
	{sizeof(disp_on291), (char *)disp_on291},
	{sizeof(disp_on292), (char *)disp_on292},
	{sizeof(disp_on293), (char *)disp_on293},
	{sizeof(disp_on294), (char *)disp_on294},
	{sizeof(disp_on295), (char *)disp_on295},
	{sizeof(disp_on296), (char *)disp_on296},
	{sizeof(disp_on297), (char *)disp_on297},
	{sizeof(disp_on298), (char *)disp_on298},
	{sizeof(disp_on299), (char *)disp_on299},
	{sizeof(disp_on300), (char *)disp_on300},
	{sizeof(disp_on301), (char *)disp_on301},
	{sizeof(disp_on302), (char *)disp_on302},
	{sizeof(disp_on303), (char *)disp_on303},
	{sizeof(disp_on304), (char *)disp_on304},
	{sizeof(disp_on305), (char *)disp_on305},
	{sizeof(disp_on306), (char *)disp_on306},
	{sizeof(disp_on307), (char *)disp_on307},
	{sizeof(disp_on308), (char *)disp_on308},
	{sizeof(disp_on309), (char *)disp_on309},
	{sizeof(disp_on310), (char *)disp_on310},
	{sizeof(disp_on311), (char *)disp_on311},
	{sizeof(disp_on312), (char *)disp_on312},
	{sizeof(disp_on313), (char *)disp_on313},
	{sizeof(disp_on314), (char *)disp_on314},
	{sizeof(disp_on315), (char *)disp_on315},
	{sizeof(disp_on316), (char *)disp_on316},
	{sizeof(disp_on317), (char *)disp_on317},
	{sizeof(disp_on318), (char *)disp_on318},
	{sizeof(disp_on319), (char *)disp_on319},
	{sizeof(disp_on320), (char *)disp_on320},
	{sizeof(disp_on321), (char *)disp_on321},
	{sizeof(disp_on322), (char *)disp_on322},
	{sizeof(disp_on323), (char *)disp_on323},
	{sizeof(disp_on324), (char *)disp_on324},
	{sizeof(disp_on325), (char *)disp_on325},
	{sizeof(disp_on326), (char *)disp_on326},
	{sizeof(disp_on327), (char *)disp_on327},
	{sizeof(disp_on328), (char *)disp_on328},
	{sizeof(disp_on329), (char *)disp_on329},
	{sizeof(disp_on330), (char *)disp_on330},
	{sizeof(disp_on331), (char *)disp_on331},
	{sizeof(disp_on332), (char *)disp_on332},
	{sizeof(disp_on333), (char *)disp_on333},
	{sizeof(disp_on334), (char *)disp_on334},
	{sizeof(disp_on335), (char *)disp_on335},
	{sizeof(disp_on336), (char *)disp_on336},
	{sizeof(disp_on337), (char *)disp_on337},
	{sizeof(disp_on338), (char *)disp_on338},
	{sizeof(disp_on339), (char *)disp_on339},
	{sizeof(disp_on340), (char *)disp_on340},
	{sizeof(disp_on341), (char *)disp_on341},
	{sizeof(disp_on342), (char *)disp_on342},
	{sizeof(disp_on343), (char *)disp_on343},
	{sizeof(disp_on344), (char *)disp_on344},
	{sizeof(disp_on345), (char *)disp_on345},
	{sizeof(disp_on346), (char *)disp_on346},
	{sizeof(disp_on347), (char *)disp_on347},
	{sizeof(disp_on348), (char *)disp_on348},
	{sizeof(disp_on349), (char *)disp_on349},
	{sizeof(disp_on350), (char *)disp_on350},
	{sizeof(disp_on351), (char *)disp_on351},
	{sizeof(disp_on352), (char *)disp_on352},
	{sizeof(disp_on353), (char *)disp_on353},
	{sizeof(disp_on354), (char *)disp_on354},
	{sizeof(disp_on355), (char *)disp_on355},
	{sizeof(disp_on356), (char *)disp_on356},
	{sizeof(disp_on357), (char *)disp_on357},
	{sizeof(disp_on358), (char *)disp_on358},
	{sizeof(disp_on359), (char *)disp_on359},
	{sizeof(disp_on360), (char *)disp_on360},
	{sizeof(disp_on361), (char *)disp_on361},
	{sizeof(disp_on362), (char *)disp_on362},
	{sizeof(disp_on363), (char *)disp_on363},
	{sizeof(disp_on364), (char *)disp_on364},
	{sizeof(disp_on365), (char *)disp_on365},
	{sizeof(disp_on366), (char *)disp_on366},
	{sizeof(disp_on367), (char *)disp_on367},
	{sizeof(disp_on368), (char *)disp_on368},
	{sizeof(disp_on369), (char *)disp_on369},
	{sizeof(disp_on370), (char *)disp_on370},
	{sizeof(disp_on371), (char *)disp_on371},
	{sizeof(disp_on372), (char *)disp_on372},
	{sizeof(disp_on373), (char *)disp_on373},
	{sizeof(disp_on374), (char *)disp_on374},
	{sizeof(disp_on375), (char *)disp_on375},
	{sizeof(disp_on376), (char *)disp_on376},
	{sizeof(disp_on377), (char *)disp_on377},
	{sizeof(disp_on378), (char *)disp_on378},
	{sizeof(disp_on379), (char *)disp_on379},
	{sizeof(disp_on380), (char *)disp_on380},
	{sizeof(disp_on381), (char *)disp_on381},
	{sizeof(disp_on382), (char *)disp_on382},
	{sizeof(disp_on383), (char *)disp_on383},
	{sizeof(disp_on384), (char *)disp_on384},
	{sizeof(disp_on385), (char *)disp_on385},
	{sizeof(disp_on386), (char *)disp_on386},
	{sizeof(disp_on387), (char *)disp_on387},
	{sizeof(disp_on388), (char *)disp_on388},
	{sizeof(disp_on389), (char *)disp_on389},
	{sizeof(disp_on390), (char *)disp_on390},
	{sizeof(disp_on391), (char *)disp_on391},
	{sizeof(disp_on392), (char *)disp_on392},
	{sizeof(disp_on393), (char *)disp_on393},
	{sizeof(disp_on394), (char *)disp_on394},
	{sizeof(disp_on395), (char *)disp_on395},
	{sizeof(disp_on396), (char *)disp_on396},
	{sizeof(disp_on397), (char *)disp_on397},
	{sizeof(disp_on398), (char *)disp_on398},
	{sizeof(disp_on399), (char *)disp_on399},
	{sizeof(disp_on400), (char *)disp_on400},
	{sizeof(disp_on401), (char *)disp_on401},
	{sizeof(disp_on402), (char *)disp_on402},
	{sizeof(disp_on403), (char *)disp_on403},
	{sizeof(disp_on404), (char *)disp_on404},
	{sizeof(disp_on405), (char *)disp_on405},
	{sizeof(disp_on406), (char *)disp_on406},
	{sizeof(disp_on407), (char *)disp_on407},
	{sizeof(disp_on408), (char *)disp_on408},
	{sizeof(disp_on409), (char *)disp_on409},
	{sizeof(disp_on410), (char *)disp_on410},
	{sizeof(disp_on411), (char *)disp_on411},
	{sizeof(disp_on412), (char *)disp_on412},
	{sizeof(disp_on413), (char *)disp_on413},
	{sizeof(disp_on414), (char *)disp_on414},
	{sizeof(disp_on415), (char *)disp_on415},
	{sizeof(disp_on416), (char *)disp_on416},
	{sizeof(disp_on417), (char *)disp_on417},
	{sizeof(disp_on418), (char *)disp_on418},
	{sizeof(disp_on419), (char *)disp_on419},
	{sizeof(disp_on420), (char *)disp_on420},
	{sizeof(disp_on421), (char *)disp_on421},
	{sizeof(disp_on422), (char *)disp_on422},
	{sizeof(disp_on423), (char *)disp_on423},
	{sizeof(disp_on424), (char *)disp_on424},
	{sizeof(disp_on425), (char *)disp_on425},
	{sizeof(disp_on426), (char *)disp_on426},
	{sizeof(disp_on427), (char *)disp_on427},
	{sizeof(disp_on428), (char *)disp_on428},
	{sizeof(disp_on429), (char *)disp_on429},
	{sizeof(disp_on430), (char *)disp_on430},
	{sizeof(disp_on431), (char *)disp_on431},
	{sizeof(disp_on432), (char *)disp_on432},
	{sizeof(disp_on433), (char *)disp_on433},
	{sizeof(disp_on434), (char *)disp_on434},
	{sizeof(disp_on435), (char *)disp_on435},
	{sizeof(disp_on436), (char *)disp_on436},
	{sizeof(disp_on437), (char *)disp_on437},
	{sizeof(disp_on438), (char *)disp_on438},
	{sizeof(disp_on439), (char *)disp_on439},
	{sizeof(disp_on440), (char *)disp_on440},
	{sizeof(disp_on441), (char *)disp_on441},
	{sizeof(disp_on442), (char *)disp_on442},
	{sizeof(disp_on443), (char *)disp_on443},
	{sizeof(disp_on444), (char *)disp_on444},
	{sizeof(disp_on445), (char *)disp_on445},
	{sizeof(disp_on446), (char *)disp_on446},
	{sizeof(disp_on447), (char *)disp_on447},
	{sizeof(disp_on448), (char *)disp_on448},
	{sizeof(disp_on449), (char *)disp_on449},
	{sizeof(disp_on450), (char *)disp_on450},
	{sizeof(disp_on451), (char *)disp_on451},
	{sizeof(disp_on452), (char *)disp_on452},
	{sizeof(disp_on453), (char *)disp_on453},
	{sizeof(disp_on454), (char *)disp_on454},
	{sizeof(disp_on455), (char *)disp_on455},
	{sizeof(disp_on456), (char *)disp_on456},
	{sizeof(disp_on457), (char *)disp_on457},
	{sizeof(disp_on458), (char *)disp_on458},
	{sizeof(disp_on459), (char *)disp_on459},
	{sizeof(disp_on460), (char *)disp_on460},
	{sizeof(disp_on461), (char *)disp_on461},
	{sizeof(disp_on462), (char *)disp_on462},
	{sizeof(disp_on463), (char *)disp_on463},
};

int mipi_nt35590_video_720p_config(void *pdata)
{
	int ret = NO_ERROR;

	/* 4 Lanes -- Enables Data Lane0, 1, 2, 3 */
	uint8_t lane_en = 0xf;
	uint64_t low_pwr_stop_mode = 0;

	/* Needed or else will have blank line at top of display */
	uint8_t eof_bllp_pwr = 0x9;
	uint8_t interleav = 0;
	struct lcdc_panel_info *lcdc = NULL;
	struct msm_panel_info *pinfo = (struct msm_panel_info *)pdata;

	dprintf(SPEW, "mipi_nt35590_video_720p_config\n");

	if (pinfo == NULL)
		return ERR_INVALID_ARGS;

	lcdc =  &(pinfo->lcdc);
	if (lcdc == NULL)
		return ERR_INVALID_ARGS;

	ret = mdss_dsi_video_mode_config((pinfo->xres + lcdc->xres_pad),
			(pinfo->yres + lcdc->yres_pad),
			(pinfo->xres),
			(pinfo->yres),
			(lcdc->h_front_porch),
			(lcdc->h_back_porch + lcdc->h_pulse_width),
			(lcdc->v_front_porch),
			(lcdc->v_back_porch + lcdc->v_pulse_width),
			(lcdc->h_pulse_width),
			(lcdc->v_pulse_width),
			pinfo->mipi.dst_format,
			pinfo->mipi.traffic_mode,
			lane_en,
			low_pwr_stop_mode,
			eof_bllp_pwr,
			interleav,
			MIPI_DSI0_BASE);
	return ret;
}

int mipi_nt35590_video_720p_on()
{
	int ret = NO_ERROR;
	dprintf(SPEW, "mipi_nt35590_video_720p_on\n");
	return ret;
}

int mipi_nt35590_video_720p_off()
{
	int ret = NO_ERROR;
	dprintf(SPEW, "mipi_nt35590_video_720p_off\n");
	return ret;
}

static struct mdss_dsi_phy_ctrl dsi_video_mode_phy_db = {
	/* 720x1280, RGB888, 4 Lane 60 fps video mode */
	/* regulator */
	{0x07, 0x09, 0x03, 0x00, 0x20, 0x00, 0x01},
	/* timing */
	{0x7d, 0x25, 0x1d, 0x00, 0x37, 0x33, 0x22, 0x27,
		0x1e, 0x03, 0x04, 0x00},
	/* phy ctrl */
	{0x5f, 0x00, 0x00, 0x10},
	/* strength */
	{0xff, 0x06},
	/* bist control */
	{0x00, 0x00, 0xb1, 0xff, 0x00, 0x00},
	/* lanes config */
	{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x97,
	 0x00, 0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x01, 0x97,
	 0x00, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x01, 0x97,
	 0x00, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x01, 0x97,
	 0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xbb},
};

void mipi_nt35590_video_720p_init(struct msm_panel_info *pinfo)
{
	if (!pinfo)
		return;

	dprintf(SPEW, "mipi_nt35590_video_720p_init\n");

	pinfo->xres = 720;
	pinfo->yres = 1280;

	pinfo->type = MIPI_VIDEO_PANEL;
	pinfo->wait_cycle = 0;
	pinfo->bpp = 24;
	pinfo->lcdc.h_back_porch = 164;
	pinfo->lcdc.h_front_porch = 140;
	pinfo->lcdc.h_pulse_width = 8;
	pinfo->lcdc.v_back_porch = 1;
	pinfo->lcdc.v_front_porch = 6;
	pinfo->lcdc.v_pulse_width = 1;
	pinfo->lcdc.border_clr = 0;	/* blk */
	pinfo->lcdc.underflow_clr = 0xff;	/* blue */
	pinfo->lcdc.hsync_skew = 0;
	pinfo->clk_rate = 424000000;

	pinfo->mipi.mode = DSI_VIDEO_MODE;
	pinfo->mipi.pulse_mode_hsa_he = TRUE;
	pinfo->mipi.hfp_power_stop = FALSE;
	pinfo->mipi.hbp_power_stop = FALSE;
	pinfo->mipi.hsa_power_stop = FALSE;
	pinfo->mipi.eof_bllp_power_stop = TRUE;
	pinfo->mipi.bllp_power_stop = TRUE;
	pinfo->mipi.traffic_mode = DSI_BURST_MODE;
	pinfo->mipi.dst_format = DSI_VIDEO_DST_FORMAT_RGB888;
	pinfo->mipi.vc = 0;
	pinfo->mipi.rgb_swap = DSI_RGB_SWAP_RGB;
	pinfo->mipi.data_lane0 = TRUE;
	pinfo->mipi.data_lane1 = TRUE;
	pinfo->mipi.data_lane2 = TRUE;
	pinfo->mipi.data_lane3 = TRUE;
	pinfo->mipi.t_clk_post = 0x20;
	pinfo->mipi.t_clk_pre = 0x2c;
	pinfo->mipi.stream = 0; /* dma_p */
	pinfo->mipi.mdp_trigger = DSI_CMD_TRIGGER_NONE;
	pinfo->mipi.dma_trigger = DSI_CMD_TRIGGER_SW;
	pinfo->mipi.frame_rate = 60;
	pinfo->mipi.mdss_dsi_phy_db = &dsi_video_mode_phy_db;
	pinfo->mipi.tx_eot_append = TRUE;

	pinfo->mipi.num_of_lanes = 4;
	pinfo->mipi.panel_cmds = nt35590_panel_video_mode_cmds;
	pinfo->mipi.num_of_panel_cmds =
				 ARRAY_SIZE(nt35590_panel_video_mode_cmds);

	pinfo->on = mipi_nt35590_video_720p_on;
	pinfo->off = mipi_nt35590_video_720p_off;
	pinfo->config = mipi_nt35590_video_720p_config;

	return;
}
